@@ -79,7 +79,7 @@ class download():
         self.ts_link_names = [x for x in r.text.split('\n')]
         self.ts_link_names = [x for x in self.ts_link_names if not x.startswith('#')]
         
-        if 'peliscdn' in self.entry.stream_url:
+        if 'fc24fc6eef71638a72a9b19699526dcb' in self.entry.stream_url:
             self.ts_links = self.ts_link_names    
             self.ts_link_names = [urlsplit(x).path for x in self.ts_link_names]
             self.ts_link_names = [x.split('/')[-1] for x in self.ts_link_names]
@@ -92,8 +92,9 @@ class download():
         try:
             r = self.session.get(ts_link, headers=self.headers)
         except:
-            pass
-        
+            self.counter += 1
+            return 
+
         file_path = self.temp_folder / fname
 
         if self.cli:
@@ -120,7 +121,7 @@ class download():
         self.counter = 0
 
         try:
-            with ThreadPoolExecutor(self.link_count / 2) as pool:
+            with ThreadPoolExecutor(60) as pool:
                 pool.map(self.download_ts, self.ts_links, self.ts_link_names)
         except KeyboardInterrupt:
             shutil.rmtree(self.temp_folder)
