@@ -1,7 +1,7 @@
 import json
 import sys
 
-from .misc import error
+from .misc import error, read_json
 from . import config
 
 class history():
@@ -18,29 +18,7 @@ class history():
        self.entry = entry
     
     def read_save_data(self):
-        """
-        Read history file, if
-        it doesn't exist create it, 
-        along with user_files folder.
-        """
-        while True:
-            try:
-                with config.history_file_path.open('r') as data:
-                    self.json = json.load(data)
-                break
-            except FileNotFoundError:
-                try:
-                    config.user_files_path.mkdir(exist_ok=True)
-                    config.history_file_path.touch(exist_ok=True)
-                    # avoids error on empty json file
-                    with config.history_file_path.open('a') as f:
-                        f.write('{}')
-                    continue
-                except PermissionError:
-                    error("Unable to create history file due to permissions.")
-                    sys.exit()
-        
-        return self.json
+        self.json = read_json(config.history_file_path)
 
     def check_duplicate(self):
         """
@@ -51,8 +29,6 @@ class history():
             if i == self.entry.show_name:
                 self.dup = True
                 return 1
-            else:
-                pass
 
         self.dup = False
 
